@@ -4,9 +4,11 @@ Marinvader - A python module for analysing alien and native marine species
 
 """
 
-from marinvaders.main import MarineLife  # noqa
-from marinvaders.main import Species  # noqa
-from marinvaders.main import plot  # noqa
-from marinvaders.main import marine_ecoregions  # noqa
+from marinvaders.main import (  # noqa  # noqa  # noqa  # noqa
+    marine_ecoregions,
+    MarineLife,
+    plot,
+    Species,
+)
 
 # from marinvaders.util.gisd_scraper import get_gisd
