@@ -21,23 +21,27 @@ More about data processing can be found at README.md and documentation
 
 import logging
 import warnings
-from typing import Union
 from pathlib import Path
+from typing import Union
 
+import geopandas as gpd
 import matplotlib.pyplot as plt
+import numpy as np
 import pandas as pd
 import shapely.geometry as sh_geo
 from matplotlib.patches import Polygon
+from shapely.errors import ShapelyDeprecationWarning
 
-import geopandas as gpd
-import numpy as np
-from marinvaders.api_calls import request_obis, obis_taxon
 from marinvaders.alien_observation import observations
-from marinvaders.readers import ShapeFiles, read_shapefile, read_redlist
+from marinvaders.api_calls import obis_taxon, request_obis
+from marinvaders.readers import read_redlist, read_shapefile, ShapeFiles
 
 # ignoring UserWarnings when using str.contains in Species.gisd() method
 warnings.filterwarnings("ignore", "This pattern has match groups")
 warnings.filterwarnings("ignore", "Geometry column does not contain geometry")
+# ignoring deprecation warnings showing when using Shapely 1.8, these warnings will not be there when Shapely is updated to 2.0.
+warnings.filterwarnings("ignore", category=DeprecationWarning)
+warnings.filterwarnings("ignore", category=ShapelyDeprecationWarning)
 
 log_filename = "marinvaders.log"
 handlers = [logging.FileHandler(log_filename)]
@@ -390,7 +394,9 @@ class MarineLife(object):
         # All species from obis which are present in the selected eco-region
         _obis = _get_obis(eco_code=eco_code)
         extra_obis_fields = obis_taxon(_obis.aphiaID.unique())
-        self._obis: pd.DataFrame = _obis.merge(extra_obis_fields, on="aphiaID", how="left")
+        self._obis: pd.DataFrame = _obis.merge(
+            extra_obis_fields, on="aphiaID", how="left"
+        )
         # All species in other db (WoRMs, GISD, NatCon)
         self._alien_observations: pd.DataFrame = observations(
             self._obis, gisd_file=gisd_file
@@ -456,8 +462,8 @@ class MarineLife(object):
         extra_obis_fields = obis_taxon(aliens.aphiaID.unique())
         df = aliens.merge(extra_obis_fields, on="aphiaID", how="left")
 
-        df['scientificName'] = df['scientificName_x']
-        df['acceptedNameUsage'] = df['acceptedNameUsage_x']
+        df["scientificName"] = df["scientificName_x"]
+        df["acceptedNameUsage"] = df["acceptedNameUsage_x"]
 
         return df[PUBLIC_HEADERS]
 
@@ -485,13 +491,13 @@ class MarineLife(object):
             df_merged = df_obis
         df_merged.drop_duplicates("aphiaID", inplace=True, keep="first")
         extra_obis_fields = obis_taxon(df_merged.aphiaID.unique())
-        df = df_merged.merge(
-            extra_obis_fields, on="aphiaID", how="left"
-        )
-        df['scientificName'] = df['scientificName_x']
-        df['acceptedNameUsage'] = df['acceptedNameUsage_x']
+        df = df_merged.merge(extra_obis_fields, on="aphiaID", how="left")
+        df["scientificName"] = df["scientificName_x"]
+        df["acceptedNameUsage"] = df["acceptedNameUsage_x"]
 
-        return df[["aphiaID", "species", "scientificName", "acceptedNameUsage", "ECO_CODE"]]
+        return df[
+            ["aphiaID", "species", "scientificName", "acceptedNameUsage", "ECO_CODE"]
+        ]
 
 
 def plot(eco_code, show: bool = True):
